@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2005 Martyn Russell <mr@gnome.org>
+ * Copyright (C) 2002-2006 Imendio AB
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -16,87 +16,90 @@
  * License along with this program; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
+ *
+ * Authors: Martyn Russell <martyn@imendio.com>
+ *          Xavier Claessens <xclaesse@gmail.com>
  */
 
 #include <config.h>
 #include <string.h>
+#include <stdlib.h>
 
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <gobject/gvaluecollector.h>
 
 #include "libgossip-marshal.h"
+#include "gossip-utils.h"
 
 #include "gossip-account.h"
 
-#define DEBUG_MSG(x) 
-/* #define DEBUG_MSG(args) g_printerr args ; g_printerr ("\n"); */
-
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_ACCOUNT, GossipAccountPriv))
 
-
 typedef struct _GossipAccountPriv GossipAccountPriv;
 
-
 struct _GossipAccountPriv {
 	gint               unique_id;
 
 	GossipAccountType  type;
-
-	gchar             *name;
 	gchar             *id;
-	gchar             *host;
-	gchar             *password;
-	gchar             *resource;
-	gchar             *server;
-	guint16            port;
-	gboolean           enabled;
+	gchar             *name;
 	gboolean           auto_connect;
-	gboolean           use_ssl;
 	gboolean           use_proxy;
+
+	GHashTable        *parameters;
 };
 
+typedef struct {
+	GossipAccountParamFunc  callback;
+	gpointer                user_data;
+	GossipAccount          *account;
+} GossipAccountParamData;
 
-static void account_class_init   (GossipAccountClass *class);
-static void account_init         (GossipAccount      *account);
-static void account_finalize     (GObject            *object);
-static void account_get_property (GObject            *object,
-				  guint               param_id,
-				  GValue             *value,
-				  GParamSpec         *pspec);
-static void account_set_property (GObject            *object,
-				  guint               param_id,
-				  const GValue       *value,
-				  GParamSpec         *pspec);
-static void account_set_type     (GossipAccount      *account,
-				  GossipAccountType   type);
-
+static void           account_class_init            (GossipAccountClass     *class);
+static void           account_init                  (GossipAccount          *account);
+static void           account_finalize              (GObject                *object);
+static void           account_get_property          (GObject                *object,
+						     guint                   param_id,
+						     GValue                 *value,
+						     GParamSpec             *pspec);
+static void           account_set_property          (GObject                *object,
+						     guint                   param_id,
+						     const GValue           *value,
+						     GParamSpec             *pspec);
+static void           account_param_new_valist      (GossipAccount          *account,
+						     const gchar            *first_param_name,
+						     va_list                 var_args);
+static void           account_param_set_valist      (GossipAccount          *account,
+						     const gchar            *first_param_name,
+						     va_list                 var_args);
+static void           account_param_get_valist      (GossipAccount          *account,
+						     const gchar            *first_param_name,
+						     va_list                 var_args);
+static void           account_param_get_all_foreach (gchar                  *param_name,
+						     GossipAccountParam     *param,
+						     GossipAccountParamData *data);
+static void           account_param_free            (GossipAccountParam     *param);
+static void           account_set_type              (GossipAccount          *account,
+						     GossipAccountType       type);
 
 enum {
 	PROP_0,
 	PROP_TYPE,
-	PROP_NAME,
 	PROP_ID,
-	PROP_PASSWORD,
-	PROP_RESOURCE,
-	PROP_SERVER,
-	PROP_PORT,
+	PROP_NAME,
 	PROP_AUTO_CONNECT,
-	PROP_USE_SSL,
 	PROP_USE_PROXY
 };
 
-
 enum {
 	CHANGED,
 	LAST_SIGNAL
 };
 
-
 static guint     signals[LAST_SIGNAL] = {0};
-
 static gpointer  parent_class = NULL;
 
-
 GType
 gossip_account_get_gtype (void)
 {
@@ -121,7 +124,6 @@ gossip_account_get_gtype (void)
 	}
 
 	return type;
-
 }
 
 static void
@@ -136,9 +138,15 @@ account_class_init (GossipAccountClass *class)
 	object_class->get_property = account_get_property;
 	object_class->set_property = account_set_property;
 
-	/* 
-	 * properties 
-	 */
+	signals[CHANGED] =
+		g_signal_new ("changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      0,
+			      NULL, NULL,
+			      libgossip_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 
 	g_object_class_install_property (object_class,
 					 PROP_TYPE,
@@ -150,6 +158,13 @@ account_class_init (GossipAccountClass *class)
 							   GOSSIP_ACCOUNT_TYPE_JABBER,
 							   G_PARAM_READWRITE));
 
+	g_object_class_install_property (object_class,
+					 PROP_ID,
+					 g_param_spec_string ("id",
+							      "Account ID",
+							      "Your unique network ID, e.g. a JID",
+							      "Myself",
+							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_NAME,
@@ -159,48 +174,6 @@ account_class_init (GossipAccountClass *class)
 							      "Default",
 							      G_PARAM_READWRITE));
 
-	g_object_class_install_property (object_class,
-					 PROP_ID,
-					 g_param_spec_string ("id",
-							      "Account ID",
-							      "For example someone@jabber.org",
-							      NULL,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class,
-					 PROP_PASSWORD,
-					 g_param_spec_string ("password",
-							      "Account Password",
-							      "Authentication token",
-							      NULL,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class,
-					 PROP_SERVER,
-					 g_param_spec_string ("server",
-							      "Account Server",
-							      "Machine to connect to",
-							      NULL,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class,
-					 PROP_RESOURCE,
-					 g_param_spec_string ("resource",
-							      "Connection Resource",
-							      "The name for the connection",
-							      NULL,
-							      G_PARAM_READWRITE));
-
-	g_object_class_install_property (object_class,
-					 PROP_PORT,
-					 g_param_spec_int ("port",
-							   "Account Port",
-							   "Port used in the connection to Server",
-							   0,
-							   65535,
-							   0,
-							   G_PARAM_READWRITE));
-
 	g_object_class_install_property (object_class,
 					 PROP_AUTO_CONNECT,
 					 g_param_spec_boolean ("auto_connect",
@@ -209,14 +182,6 @@ account_class_init (GossipAccountClass *class)
 							       TRUE,
 							       G_PARAM_READWRITE));
 
-	g_object_class_install_property (object_class,
-					 PROP_USE_SSL,
-					 g_param_spec_boolean ("use_ssl",
-							       "Account Uses SSL",
-							       "Identifies if the connection uses secure methods",
-							       FALSE,
-							       G_PARAM_READWRITE));
-	
 	g_object_class_install_property (object_class,
 					 PROP_USE_PROXY,
 					 g_param_spec_boolean ("use_proxy",
@@ -224,22 +189,6 @@ account_class_init (GossipAccountClass *class)
 							       "Identifies if the connection uses the environment proxy",
 							       FALSE,
 							       G_PARAM_READWRITE));
-	
-	
-	/*
-	 * signals
-	 */
-
-        signals[CHANGED] = 
-		g_signal_new ("changed",
-			      G_TYPE_FROM_CLASS (object_class),
-                              G_SIGNAL_RUN_LAST,
-			      0, 
-			      NULL, NULL,
-			      libgossip_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
-
 
 	g_type_class_add_private (object_class, sizeof (GossipAccountPriv));
 }
@@ -249,36 +198,33 @@ account_init (GossipAccount *account)
 {
 	GossipAccountPriv *priv;
 	static gint        id = 1;
- 
+
 	priv = GET_PRIV (account);
 
 	priv->unique_id    = id++;
 
 	priv->type         = 0;
-	priv->name         = NULL;
 	priv->id           = NULL;
-	priv->password     = NULL;
-	priv->resource     = NULL;
-	priv->server       = NULL;
-	priv->port         = 0;
-	priv->enabled      = TRUE;
+	priv->name         = NULL;
 	priv->auto_connect = TRUE;
-	priv->use_ssl      = FALSE;
 	priv->use_proxy    = FALSE;
+
+	priv->parameters = g_hash_table_new_full (g_str_hash,
+						  g_str_equal,
+						  g_free,
+						  (GDestroyNotify)account_param_free);
 }
 
 static void
 account_finalize (GObject *object)
 {
 	GossipAccountPriv *priv;
-	
+
 	priv = GET_PRIV (object);
-	
-	g_free (priv->name);
+
 	g_free (priv->id);
-	g_free (priv->password);
-	g_free (priv->resource);
-	g_free (priv->server);
+	g_free (priv->name);
+	g_hash_table_unref (priv->parameters);
 
 	(G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
@@ -290,37 +236,24 @@ account_get_property (GObject    *object,
 		      GParamSpec *pspec)
 {
 	GossipAccountPriv *priv;
-	
+	GossipAccount     *account;
+
 	priv = GET_PRIV (object);
+	account = GOSSIP_ACCOUNT (object);
 
 	switch (param_id) {
 	case PROP_TYPE:
 		g_value_set_int (value, priv->type);
 		break;
-	case PROP_NAME:
-		g_value_set_string (value, priv->name);
-		break;
 	case PROP_ID:
 		g_value_set_string (value, priv->id);
 		break;
-	case PROP_PASSWORD:
-		g_value_set_string (value, priv->password);
-		break;
-	case PROP_RESOURCE:
-		g_value_set_string (value, priv->resource);
-		break;
-	case PROP_SERVER:
-		g_value_set_string (value, priv->server);
-		break;
-	case PROP_PORT:
-		g_value_set_int (value, priv->port);
+	case PROP_NAME:
+		g_value_set_string (value, priv->name);
 		break;
 	case PROP_AUTO_CONNECT:
 		g_value_set_boolean (value, priv->auto_connect);
 		break;
-	case PROP_USE_SSL:
-		g_value_set_boolean (value, priv->use_ssl);
-		break;
 	case PROP_USE_PROXY:
 		g_value_set_boolean (value, priv->use_proxy);
 		break;
@@ -329,7 +262,7 @@ account_get_property (GObject    *object,
 		break;
 	};
 }
-	
+
 static void
 account_set_property (GObject      *object,
 		      guint         param_id,
@@ -337,46 +270,26 @@ account_set_property (GObject      *object,
 		      GParamSpec   *pspec)
 {
 	GossipAccountPriv *priv;
-	
+
 	priv = GET_PRIV (object);
-	
+
 	switch (param_id) {
 	case PROP_TYPE:
 		account_set_type (GOSSIP_ACCOUNT (object),
 				  g_value_get_int (value));
 		break;
+	case PROP_ID:
+		gossip_account_set_id (GOSSIP_ACCOUNT (object),
+					 g_value_get_string (value));
+		break;
 	case PROP_NAME:
 		gossip_account_set_name (GOSSIP_ACCOUNT (object),
 					 g_value_get_string (value));
 		break;
-	case PROP_ID:
-		gossip_account_set_id (GOSSIP_ACCOUNT (object),
-				       g_value_get_string (value));
-		break;
-	case PROP_PASSWORD:
-		gossip_account_set_password (GOSSIP_ACCOUNT (object),
-					     g_value_get_string (value));
-		break;
-	case PROP_RESOURCE:
-		gossip_account_set_resource (GOSSIP_ACCOUNT (object),
-					     g_value_get_string (value));
-		break;
-	case PROP_SERVER:
-		gossip_account_set_server (GOSSIP_ACCOUNT (object),
-					   g_value_get_string (value));
-		break;
-	case PROP_PORT:
-		gossip_account_set_port (GOSSIP_ACCOUNT (object),
-					 g_value_get_int (value));
-		break;
 	case PROP_AUTO_CONNECT:
 		gossip_account_set_auto_connect (GOSSIP_ACCOUNT (object),
 						 g_value_get_boolean (value));
 		break;
-	case PROP_USE_SSL:
-		gossip_account_set_use_ssl (GOSSIP_ACCOUNT (object),
-					    g_value_get_boolean (value));
-		break;
 	case PROP_USE_PROXY:
 		gossip_account_set_use_proxy (GOSSIP_ACCOUNT (object),
 					    g_value_get_boolean (value));
@@ -388,41 +301,284 @@ account_set_property (GObject      *object,
 }
 
 static void
-account_set_type (GossipAccount     *account,
-		  GossipAccountType  type)
+account_param_new_valist (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  va_list        var_args)
 {
 	GossipAccountPriv *priv;
+	const gchar       *name;
+
+	priv = GET_PRIV (account);
+
+	for (name = first_param_name; name; name = va_arg (var_args, gchar*)) {
+		GossipAccountParam *param;
+		GType               g_type;
+		gchar              *error = NULL;
+
+		param = g_hash_table_lookup (priv->parameters, name);
+		if (param) {
+			g_warning ("GossipAccount already has a parameter named `%s'", name);
+			break;
+		}
+
+		param = g_slice_new0 (GossipAccountParam);
+
+		g_type = va_arg (var_args, GType);
+		g_value_init (&param->g_value, g_type);
+
+		G_VALUE_COLLECT (&param->g_value, var_args, 0, &error);
+		if (error) {
+			g_warning ("%s: %s", G_STRFUNC, error);
+			g_free (error);
+			break;
+		}
+
+		param->flags = va_arg (var_args, GossipAccountParamFlags);
+
+		g_hash_table_insert (priv->parameters,
+				     g_strdup (name),
+				     param);
+	}
+}
+
+static void
+account_param_set_valist (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  va_list        var_args)
+{
+	GossipAccountPriv *priv;
+	const gchar       *name;
+
+	priv = GET_PRIV (account);
+
+	for (name = first_param_name; name; name = va_arg (var_args, gchar*)) {
+		GossipAccountParam *param;
+		gchar              *error = NULL;
+
+		param = g_hash_table_lookup (priv->parameters, name);
+		if (!param) {
+			g_warning ("GossipAccount has no parameter named `%s'", name);
+			break;
+		}
+
+		G_VALUE_COLLECT (&param->g_value, var_args, 0, &error);
+		if (error) {
+			g_warning ("%s: %s", G_STRFUNC, error);
+			g_free (error);
+			break;
+		}
+	}
+}
+
+static void
+account_param_get_valist (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  va_list        var_args)
+{
+	GossipAccountPriv *priv;
+	const gchar       *name;
+
+	priv = GET_PRIV (account);
+
+	for (name = first_param_name; name; name = va_arg (var_args, gchar*)) {
+		GossipAccountParam *param;
+		gchar              *error = NULL;
+
+		param = g_hash_table_lookup (priv->parameters, name);
+		if (!param) {
+			g_warning ("GossipAccount has no parameter named `%s'", name);
+			break;
+		}
+
+		G_VALUE_LCOPY (&param->g_value, var_args, 0, &error);
+		if (error) {
+			g_warning ("%s: %s", G_STRFUNC, error);
+			g_free (error);
+			break;
+		}
+	}
+}
+
+void
+gossip_account_param_new (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  ...)
+{
+	va_list var_args;
+
+	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
+
+	va_start (var_args, first_param_name);
+	account_param_new_valist (account, first_param_name, var_args);
+	va_end (var_args);
+
+	g_signal_emit (account, signals[CHANGED], 0);
+}
+
+void
+gossip_account_param_new_g_value (GossipAccount           *account,
+				  const gchar             *param_name,
+				  const GValue            *g_value,
+				  GossipAccountParamFlags  flags)
+{
+	GossipAccountParam *param;
+	GossipAccountPriv  *priv;
+
+	priv = GET_PRIV (account);
+
+	param = g_hash_table_lookup (priv->parameters, param_name);
+	if (param) {
+		g_warning ("GossipAccount already has a parameter named `%s'", param_name);
+		return;
+	}
+	param = g_new0 (GossipAccountParam, 1);
+
+	g_value_init (&param->g_value, G_VALUE_TYPE (g_value));
+	g_value_copy (g_value, &param->g_value);
+	param->flags = flags;
+
+	g_hash_table_insert (priv->parameters,
+			     g_strdup (param_name),
+			     param);
+}
+
+void
+gossip_account_param_set (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  ...)
+{
+	va_list var_args;
+
+	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
+
+	va_start (var_args, first_param_name);
+	account_param_set_valist (account, first_param_name, var_args);
+	va_end (var_args);
+
+	g_signal_emit (account, signals[CHANGED], 0);
+}
+
+void
+gossip_account_param_set_g_value (GossipAccount           *account,
+				  const gchar             *param_name,
+				  const GValue            *g_value)
+{
+	GossipAccountPriv  *priv;
+	GossipAccountParam *param;
 
 	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
 
 	priv = GET_PRIV (account);
-	priv->type = type;
+
+	param = g_hash_table_lookup (priv->parameters, param_name);
+	if (!param) {
+		g_warning ("GossipAccount has no parameter named `%s'", param_name);
+		return;
+	}
+
+	g_value_copy (g_value, &param->g_value);
 
 	g_signal_emit (account, signals[CHANGED], 0);
 }
 
+void
+gossip_account_param_get (GossipAccount *account,
+			  const gchar   *first_param_name,
+			  ...)
+{
+	va_list var_args;
+
+	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
+
+	va_start (var_args, first_param_name);
+	account_param_get_valist (account, first_param_name, var_args);
+	va_end (var_args);
+}
+
+const GValue *
+gossip_account_param_get_g_value (GossipAccount *account,
+				  const gchar   *param_name)
+{
+	GossipAccountPriv  *priv;
+	GossipAccountParam *param;
+
+	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
+
+	priv = GET_PRIV (account);
+
+	param = g_hash_table_lookup (priv->parameters, param_name);
+	if (!param) {
+		g_warning ("GossipAccount has no parameter named `%s'", param_name);
+		return NULL;
+	}
+
+	return &param->g_value;
+}
+
+gboolean
+gossip_account_has_param (GossipAccount *account,
+			  const gchar   *param_name)
+{
+	GossipAccountPriv      *priv;
+
+	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), FALSE);
+
+	priv = GET_PRIV (account);
+
+	return g_hash_table_lookup (priv->parameters, param_name) != NULL;
+}
+
+void
+gossip_account_param_foreach (GossipAccount           *account,
+			      GossipAccountParamFunc   callback,
+			      gpointer                 user_data)
+{
+	GossipAccountPriv      *priv;
+	GossipAccountParamData *data;
+
+	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
+
+	priv = GET_PRIV (account);
+
+	data = g_new0 (GossipAccountParamData, 1);
+	data->callback = callback;
+	data->user_data = user_data;
+	data->account = account;
+
+	g_hash_table_foreach (priv->parameters,
+			      (GHFunc) account_param_get_all_foreach,
+			      data);
+}
+
+static void
+account_param_get_all_foreach (gchar                  *param_name,
+			       GossipAccountParam     *param,
+			       GossipAccountParamData *data)
+{
+	data->callback (data->account,
+			param_name,
+			param,
+			data->user_data);
+}
+
+static void
+account_param_free (GossipAccountParam *param)
+{
+	g_value_unset (&param->g_value);
+	g_slice_free (GossipAccountParam, param);
+}
+
 GossipAccountType
 gossip_account_get_type (GossipAccount *account)
 {
 	GossipAccountPriv *priv;
 
 	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), 0);
-	
+
 	priv = GET_PRIV (account);
 	return priv->type;
 }
 
-const gchar *
-gossip_account_get_name (GossipAccount *account)
-{
-	GossipAccountPriv *priv;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
-
-	priv = GET_PRIV (account);
-	return priv->name;
-}
-
 const gchar *
 gossip_account_get_id (GossipAccount *account)
 {
@@ -435,47 +591,14 @@ gossip_account_get_id (GossipAccount *account)
 }
 
 const gchar *
-gossip_account_get_password (GossipAccount *account)
+gossip_account_get_name (GossipAccount *account)
 {
 	GossipAccountPriv *priv;
 
 	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
 
 	priv = GET_PRIV (account);
-	return priv->password;
-}
-
-const gchar *
-gossip_account_get_resource (GossipAccount *account)
-{
-	GossipAccountPriv *priv;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
-
-	priv = GET_PRIV (account);
-	return priv->resource;
-}
-
-const gchar *
-gossip_account_get_server (GossipAccount *account)
-{
-	GossipAccountPriv *priv;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), NULL);
-
-	priv = GET_PRIV (account);
-	return priv->server;
-}
-
-guint16
-gossip_account_get_port (GossipAccount *account)
-{
-	GossipAccountPriv *priv;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), 0);
-
-	priv = GET_PRIV (account);
-	return priv->port;
+	return priv->name;
 }
 
 gboolean
@@ -489,17 +612,6 @@ gossip_account_get_auto_connect (GossipAccount *account)
 	return priv->auto_connect;
 }
 
-gboolean
-gossip_account_get_use_ssl (GossipAccount *account)
-{
-	GossipAccountPriv *priv;
-
-	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (account), FALSE);
-
-	priv = GET_PRIV (account);
-	return priv->use_ssl;
-}
-
 gboolean
 gossip_account_get_use_proxy (GossipAccount *account)
 {
@@ -511,22 +623,17 @@ gossip_account_get_use_proxy (GossipAccount *account)
 	return priv->use_proxy;
 }
 
-
-void 
-gossip_account_set_name (GossipAccount *account,
-			 const gchar   *name)
+void
+account_set_type (GossipAccount     *account,
+		  GossipAccountType  type)
 {
 	GossipAccountPriv *priv;
 
 	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-	g_return_if_fail (name != NULL);
-	
-	priv = GET_PRIV (account);
-	
-	g_free (priv->name);
-	priv->name = g_strdup (name);
 
-	g_object_notify (G_OBJECT (account), "name");
+	priv = GET_PRIV (account);
+	priv->type = type;
+
 	g_signal_emit (account, signals[CHANGED], 0);
 }
 
@@ -538,7 +645,7 @@ gossip_account_set_id (GossipAccount *account,
 
 	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
 	g_return_if_fail (id != NULL);
-	
+
 	priv = GET_PRIV (account);
 
 	g_free (priv->id);
@@ -549,86 +656,20 @@ gossip_account_set_id (GossipAccount *account,
 }
 
 void
-gossip_account_set_password (GossipAccount *account,
-			     const gchar   *password)
+gossip_account_set_name (GossipAccount *account,
+			 const gchar   *name)
 {
 	GossipAccountPriv *priv;
 
 	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-	g_return_if_fail (password != NULL);
-	
-	priv = GET_PRIV (account);
-	
-	g_free (priv->password);
-	priv->password = g_strdup (password);
-
-	g_object_notify (G_OBJECT (account), "password");
-	g_signal_emit (account, signals[CHANGED], 0);
-}
-
-void
-gossip_account_set_resource (GossipAccount *account,
-			     const gchar   *resource)
-{
-	GossipAccountPriv *priv;
-
-	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-	g_return_if_fail (resource != NULL);
+	g_return_if_fail (name != NULL);
 
 	priv = GET_PRIV (account);
-	
-	g_free (priv->resource);
-	priv->resource = g_strdup (resource);
 
-	g_object_notify (G_OBJECT (account), "resource");
-	g_signal_emit (account, signals[CHANGED], 0);
-}
+	g_free (priv->name);
+	priv->name = g_strdup (name);
 
-void
-gossip_account_set_server (GossipAccount *account,
-			   const gchar   *server)
-{
-	GossipAccountPriv *priv;
-
-	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-	g_return_if_fail (server != NULL);
-
-	priv = GET_PRIV (account);
-	
-	g_free (priv->server);
-	priv->server = g_strdup (server);
-
-	g_object_notify (G_OBJECT (account), "server");
-	g_signal_emit (account, signals[CHANGED], 0);
-}
-
-void
-gossip_account_set_port (GossipAccount *account,
-			 guint16        port)
-{
-	GossipAccountPriv *priv;
-
-	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-
-	priv = GET_PRIV (account);
-	priv->port = port;
-
-	g_object_notify (G_OBJECT (account), "port");
-	g_signal_emit (account, signals[CHANGED], 0);
-}
-
-void
-gossip_account_set_enabled (GossipAccount *account,
-			    gboolean       enabled)
-{
-	GossipAccountPriv *priv;
-
-	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-
-	priv = GET_PRIV (account);
-	priv->enabled = enabled;
-
-	g_object_notify (G_OBJECT (account), "enabled");
+	g_object_notify (G_OBJECT (account), "name");
 	g_signal_emit (account, signals[CHANGED], 0);
 }
 
@@ -647,21 +688,6 @@ gossip_account_set_auto_connect (GossipAccount *account,
 	g_signal_emit (account, signals[CHANGED], 0);
 }
 
-void
-gossip_account_set_use_ssl (GossipAccount *account,
- 			    gboolean       use_ssl)
-{
-	GossipAccountPriv *priv;
-
-	g_return_if_fail (GOSSIP_IS_ACCOUNT (account));
-
-	priv = GET_PRIV (account);
-	priv->use_ssl = use_ssl;
-
-	g_object_notify (G_OBJECT (account), "use_ssl");
-	g_signal_emit (account, signals[CHANGED], 0);
-}
-
 void
 gossip_account_set_use_proxy (GossipAccount *account,
 			      gboolean       use_proxy)
@@ -677,11 +703,11 @@ gossip_account_set_use_proxy (GossipAccount *account,
 	g_signal_emit (account, signals[CHANGED], 0);
 }
 
-guint 
+guint
 gossip_account_hash (gconstpointer key)
 {
 	GossipAccountPriv *priv;
-	
+
 	g_return_val_if_fail (GOSSIP_IS_ACCOUNT (key), 0);
 
 	priv = GET_PRIV (key);
@@ -690,7 +716,7 @@ gossip_account_hash (gconstpointer key)
 }
 
 gboolean
-gossip_account_equal (gconstpointer a, 
+gossip_account_equal (gconstpointer a,
 		      gconstpointer b)
 {
 	GossipAccountPriv *priv1;
@@ -709,14 +735,38 @@ const gchar *
 gossip_account_type_to_string (GossipAccountType type)
 {
 	switch (type) {
-	case GOSSIP_ACCOUNT_TYPE_JABBER: return "Jabber";
-	case GOSSIP_ACCOUNT_TYPE_AIM:    return "AIM";
-	case GOSSIP_ACCOUNT_TYPE_ICQ:    return "ICQ";
-	case GOSSIP_ACCOUNT_TYPE_MSN:    return "MSN";
-	case GOSSIP_ACCOUNT_TYPE_YAHOO:  return "Yahoo!";
+	case GOSSIP_ACCOUNT_TYPE_JABBER:  return "Jabber";
+	case GOSSIP_ACCOUNT_TYPE_AIM:     return "AIM";
+	case GOSSIP_ACCOUNT_TYPE_ICQ:     return "ICQ";
+	case GOSSIP_ACCOUNT_TYPE_MSN:     return "MSN";
+	case GOSSIP_ACCOUNT_TYPE_YAHOO:   return "Yahoo!";
+
+	case GOSSIP_ACCOUNT_TYPE_UNKNOWN:
+	default:
+		break;
 	}
 
-	return "";
+	return "Unknown";
 }
 
+GossipAccountType
+gossip_account_string_to_type (const gchar *str)
+{
+	if (gossip_strncasecmp (str, "Jabber", -1) == 0) {
+		return GOSSIP_ACCOUNT_TYPE_JABBER;
+	}
+	else if (gossip_strncasecmp (str, "AIM", -1) == 0) {
+		return GOSSIP_ACCOUNT_TYPE_AIM;
+	}
+	else if (gossip_strncasecmp (str, "ICQ", -1) == 0) {
+		return GOSSIP_ACCOUNT_TYPE_ICQ;
+	}
+	else if (gossip_strncasecmp (str, "MSN", -1) == 0) {
+		return GOSSIP_ACCOUNT_TYPE_MSN;
+	}
+	else if (gossip_strncasecmp (str, "Yahoo!", -1) == 0) {
+		return GOSSIP_ACCOUNT_TYPE_YAHOO;
+	}
 
+	return GOSSIP_ACCOUNT_TYPE_UNKNOWN;
+}
