@@ -24,13 +24,14 @@
 #include <string.h>
 
 #include "gossip-account.h"
+#include "gossip-avatar.h"
 #include "gossip-contact.h"
 #include "gossip-utils.h"
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_CONTACT, GossipContactPriv))
 
 /* Make sure any additions to the private contact structure are copied
- * in the gossip_contact_copy() function further down.
+ * in the gossip_contact_copy_values() function further down.
  */
 typedef struct _GossipContactPriv GossipContactPriv;
 
@@ -44,34 +45,35 @@ struct _GossipContactPriv {
 	GList              *groups;
 
 	GossipSubscription  subscription;
-
-	guchar             *avatar;
-	guint               avatar_size;
-
+	GossipAvatar       *avatar;
 	GossipAccount      *account;
 };
 
-static void contact_class_init   (GossipContactClass *class);
-static void contact_init         (GossipContact      *contact);
-static void contact_finalize     (GObject            *object);
-static void contact_get_property (GObject            *object,
-				  guint               param_id,
-				  GValue             *value,
-				  GParamSpec         *pspec);
-static void contact_set_property (GObject            *object,
-				  guint               param_id,
-				  const GValue       *value,
-				  GParamSpec         *pspec);
+static void contact_class_init    (GossipContactClass *class);
+static void contact_init          (GossipContact      *contact);
+static void contact_finalize      (GObject            *object);
+static void contact_get_property  (GObject            *object,
+				   guint               param_id,
+				   GValue             *value,
+				   GParamSpec         *pspec);
+static void contact_set_property  (GObject            *object,
+				   guint               param_id,
+				   const GValue       *value,
+				   GParamSpec         *pspec);
+static void contact_set_type      (GossipContact      *contact,
+				   GossipContactType   type);
+static void contact_set_presences (GossipContact      *contact,
+				   GList              *presences);
 
 enum {
 	PROP_0,
 	PROP_TYPE,
 	PROP_NAME,
 	PROP_ID,
-	PROP_ACTIVE_PRESENCE,
+	PROP_PRESENCES,
+	PROP_GROUPS,
 	PROP_SUBSCRIPTION,
 	PROP_AVATAR,
-	PROP_AVATAR_SIZE,
 	PROP_ACCOUNT
 };
 
@@ -142,12 +144,18 @@ contact_class_init (GossipContactClass *class)
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
-					 PROP_ACTIVE_PRESENCE,
-					 g_param_spec_object ("active-presence",
-							      "Contact active presence",
-							      "Current presence of contact",
-							      GOSSIP_TYPE_PRESENCE,
-							      G_PARAM_READABLE));
+					 PROP_PRESENCES,
+					 g_param_spec_pointer ("presences",
+							       "Contact presences",
+							       "Presences of contact",
+							       G_PARAM_READWRITE));
+
+	g_object_class_install_property (object_class,
+					 PROP_GROUPS,
+					 g_param_spec_pointer ("groups",
+							       "Contact groups",
+							       "Groups of contact",
+							       G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_SUBSCRIPTION,
@@ -165,15 +173,6 @@ contact_class_init (GossipContactClass *class)
 							       "Avatar image",
 							       "The avatar image",
 							       G_PARAM_READWRITE));
-	g_object_class_install_property (object_class,
-					 PROP_AVATAR_SIZE,
-					 g_param_spec_uint ("avatar_size",
-							    "Avatar size",
-							    "The size of the avatar image",
-							    0,
-							    G_MAXUINT,
-							    0,
-							    G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_ACCOUNT,
@@ -200,7 +199,6 @@ contact_init (GossipContact *contact)
 	priv->account     = NULL;
 	priv->groups      = NULL;
 	priv->avatar      = NULL;
-	priv->avatar_size = 0;
 }
 
 static void
@@ -212,7 +210,10 @@ contact_finalize (GObject *object)
 
 	g_free (priv->name);
 	g_free (priv->id);
-	g_free (priv->avatar);
+
+	if (priv->avatar) {
+		gossip_avatar_unref (priv->avatar);
+	}
 
 	if (priv->presences) {
 		g_list_foreach (priv->presences, (GFunc) g_object_unref, NULL);
@@ -224,7 +225,9 @@ contact_finalize (GObject *object)
 		g_list_free (priv->groups);
 	}
 
-	g_object_unref (priv->account);
+	if (priv->account) {
+		g_object_unref (priv->account);
+	}
 
 	(G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
@@ -251,12 +254,11 @@ contact_get_property (GObject    *object,
 		g_value_set_string (value,
 				    gossip_contact_get_id (GOSSIP_CONTACT (object)));
 		break;
-	case PROP_ACTIVE_PRESENCE:
-		if (priv->presences) {
-			g_value_set_object (value, G_OBJECT (priv->presences->data));
-		} else {
-			g_value_set_object (value, NULL);
-		}
+	case PROP_PRESENCES:
+		g_value_set_pointer (value, priv->presences);
+		break;
+	case PROP_GROUPS:
+		g_value_set_pointer (value, priv->groups);
 		break;
 	case PROP_SUBSCRIPTION:
 		g_value_set_int (value, priv->subscription);
@@ -264,9 +266,6 @@ contact_get_property (GObject    *object,
 	case PROP_AVATAR:
 		g_value_set_pointer (value, priv->avatar);
 		break;
-	case PROP_AVATAR_SIZE:
-		g_value_set_uint (value, priv->avatar_size);
-		break;
 	case PROP_ACCOUNT:
 		if (priv->account) {
 			g_value_set_object (value, G_OBJECT (priv->account));
@@ -292,7 +291,8 @@ contact_set_property (GObject      *object,
 
 	switch (param_id) {
 	case PROP_TYPE:
-		priv->type = g_value_get_int (value);
+		contact_set_type (GOSSIP_CONTACT (object),
+				  g_value_get_int (value));
 		break;
 	case PROP_NAME:
 		gossip_contact_set_name (GOSSIP_CONTACT (object),
@@ -302,14 +302,21 @@ contact_set_property (GObject      *object,
 		gossip_contact_set_id (GOSSIP_CONTACT (object),
 				       g_value_get_string (value));
 		break;
+	case PROP_PRESENCES:
+		contact_set_presences (GOSSIP_CONTACT (object),
+				       g_value_get_pointer (value));
+		break;
+	case PROP_GROUPS:
+		gossip_contact_set_groups (GOSSIP_CONTACT (object),
+					   g_value_get_pointer (value));
+		break;
 	case PROP_SUBSCRIPTION:
-		priv->subscription = g_value_get_int (value);
+		gossip_contact_set_subscription (GOSSIP_CONTACT (object),
+						 g_value_get_int (value));
 		break;
 	case PROP_AVATAR:
-		priv->avatar = g_value_get_pointer (value);
-		break;
-	case PROP_AVATAR_SIZE:
-		priv->avatar_size = g_value_get_uint (value);
+		gossip_contact_set_avatar (GOSSIP_CONTACT (object),
+					   g_value_get_pointer (value));
 		break;
 	case PROP_ACCOUNT:
 		gossip_contact_set_account (GOSSIP_CONTACT (object),
@@ -348,41 +355,34 @@ gossip_contact_new_full (GossipContactType  type,
 GossipContact *
 gossip_contact_copy (GossipContact *contact)
 {
-	GossipContact     *new_contact;
-	GossipContactPriv *new_priv;
-	GossipContactPriv *priv;
-	GList             *l;
+	GossipContact *new_contact;
 
-	g_return_val_if_fail (GOSSIP_IS_CONTACT (contact), NULL);
-
-	priv = GET_PRIV (contact);
-
-	new_contact = gossip_contact_new_full (priv->type,
-					       priv->account,
-					       priv->id,
-					       priv->name);
-
-	new_priv = GET_PRIV (new_contact);
-
-	new_priv->subscription = priv->subscription;
-
-	for (l = priv->groups; l; l = l->next) {
-		new_priv->groups = g_list_prepend (new_priv->groups,
-						   g_strdup (l->data));
-	}
-
-	priv->groups = g_list_reverse (priv->groups);
-
-	for (l = priv->presences; l; l = l->next) {
-		new_priv->presences = g_list_prepend (new_priv->presences,
-						      g_strdup (l->data));
-	}
-	
-	priv->presences = g_list_reverse (priv->presences);
+	new_contact = g_object_new (GOSSIP_TYPE_CONTACT, NULL);
+	gossip_contact_copy_values (contact, new_contact);
 
 	return new_contact;
 }
 
+void
+gossip_contact_copy_values (GossipContact *contact_from,
+			    GossipContact *contact_to)
+{
+	GossipContactPriv *from_priv;
+
+	g_return_if_fail (GOSSIP_IS_CONTACT (contact_from));
+	g_return_if_fail (GOSSIP_IS_CONTACT (contact_to));
+
+	from_priv = GET_PRIV (contact_from);
+
+	gossip_contact_set_name (contact_to, from_priv->name);
+	gossip_contact_set_id (contact_to, from_priv->id);
+	gossip_contact_set_subscription (contact_to, from_priv->subscription);
+	gossip_contact_set_avatar (contact_to, from_priv->avatar);
+	gossip_contact_set_account (contact_to, from_priv->account);
+	gossip_contact_set_groups (contact_to, from_priv->groups);
+	contact_set_presences (contact_to, from_priv->presences);
+}
+
 GossipContactType
 gossip_contact_get_type (GossipContact *contact)
 {
@@ -428,22 +428,16 @@ gossip_contact_get_name (GossipContact *contact)
 	return priv->name;
 }
 
-const guchar *
-gossip_contact_get_avatar (GossipContact *contact,
-			   gsize         *avatar_size)
+GossipAvatar *
+gossip_contact_get_avatar (GossipContact *contact)
 {
 	GossipContactPriv *priv;
-	guchar            *avatar;
 
 	g_return_val_if_fail (GOSSIP_IS_CONTACT (contact), NULL);
-	g_return_val_if_fail (avatar_size != NULL, NULL);
 
 	priv = GET_PRIV (contact);
 
-	avatar = (guchar*) priv->avatar;
-	*avatar_size = priv->avatar_size;
-
-	return avatar;
+	return priv->avatar;
 }
 
 GossipAccount *
@@ -536,6 +530,19 @@ gossip_contact_get_subscription (GossipContact *contact)
 	return priv->subscription;
 }
 
+static void
+contact_set_type (GossipContact      *contact,
+		  GossipContactType   type)
+{
+	GossipContactPriv *priv;
+
+	priv = GET_PRIV (contact);
+
+	priv->type = type;
+
+	g_object_notify (G_OBJECT (contact), "type");
+}
+
 void
 gossip_contact_set_id (GossipContact *contact,
 		       const gchar   *id)
@@ -570,10 +577,28 @@ gossip_contact_set_name (GossipContact *contact,
 	g_object_notify (G_OBJECT (contact), "name");
 }
 
+static void
+contact_set_presences (GossipContact *contact,
+		       GList         *presences)
+{
+	GossipContactPriv *priv;
+
+	priv = GET_PRIV (contact);
+
+	if (priv->presences) {
+		g_list_foreach (priv->presences, (GFunc) g_object_unref, NULL);
+		g_list_free (priv->presences);
+	}
+
+	priv->presences = g_list_copy (presences);
+	g_list_foreach (priv->presences, (GFunc) g_object_ref, NULL);
+
+	g_object_notify (G_OBJECT (contact), "presences");
+}
+
 void
 gossip_contact_set_avatar (GossipContact *contact,
-			   const guchar  *avatar,
-			   gsize          avatar_size)
+			   GossipAvatar  *avatar)
 {
 	GossipContactPriv *priv;
 
@@ -581,18 +606,16 @@ gossip_contact_set_avatar (GossipContact *contact,
 
 	priv = GET_PRIV (contact);
 
-	g_free (priv->avatar);
-
-	if (avatar) {
-		priv->avatar = g_memdup (avatar, avatar_size);
-		priv->avatar_size = avatar_size;
-	} else {
+	if (priv->avatar) {
+		gossip_avatar_unref (priv->avatar);
 		priv->avatar = NULL;
-		priv->avatar_size = 0;
+	}
+	
+	if (avatar) {
+		priv->avatar = gossip_avatar_ref (avatar);
 	}
 
 	g_object_notify (G_OBJECT (contact), "avatar");
-	g_object_notify (G_OBJECT (contact), "avatar-size");
 }
 
 void
@@ -663,6 +686,8 @@ gossip_contact_add_presence (GossipContact  *contact,
 	priv->presences = g_list_insert_sorted (priv->presences, 
 						g_object_ref (presence),
 						gossip_presence_sort_func);
+
+	g_object_notify (G_OBJECT (contact), "presences");
 }
 
 void
@@ -707,16 +732,18 @@ gossip_contact_remove_presence (GossipContact  *contact,
 
 	priv->presences = g_list_sort (priv->presences,
 				       gossip_presence_sort_func);
+
+	g_object_notify (G_OBJECT (contact), "presences");
 }
 
-gboolean
+void
 gossip_contact_set_groups (GossipContact *contact,
 			   GList         *groups)
 {
 	GossipContactPriv *priv;
 	GList             *old_groups, *l;
 
-	g_return_val_if_fail (GOSSIP_IS_CONTACT (contact), FALSE);
+	g_return_if_fail (GOSSIP_IS_CONTACT (contact));
 
 	priv = GET_PRIV (contact);
 
@@ -731,7 +758,7 @@ gossip_contact_set_groups (GossipContact *contact,
 	g_list_foreach (old_groups, (GFunc) g_free, NULL);
 	g_list_free (old_groups);
 
-	return TRUE;
+	g_object_notify (G_OBJECT (contact), "groups");
 }
 
 void
