@@ -23,6 +23,8 @@
 
 #include <glib-object.h>
 
+G_BEGIN_DECLS
+
 #define GOSSIP_TYPE_EVENT         (gossip_event_get_gtype ())
 #define GOSSIP_EVENT(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_EVENT, GossipEvent))
 #define GOSSIP_EVENT_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST ((k), GOSSIP_TYPE_EVENT, GossipEventClass))
@@ -33,6 +35,8 @@
 typedef struct _GossipEvent      GossipEvent;
 typedef struct _GossipEventClass GossipEventClass;
 
+typedef gint GossipEventId;
+
 struct _GossipEvent {
 	GObject parent;
 };
@@ -42,7 +46,7 @@ struct _GossipEventClass {
 };
 
 typedef enum {
-        GOSSIP_EVENT_NEW_MESSAGE,
+	GOSSIP_EVENT_NEW_MESSAGE,
 	GOSSIP_EVENT_SUBSCRIPTION_REQUEST,
 	GOSSIP_EVENT_SERVER_MESSAGE,
 	GOSSIP_EVENT_FILE_TRANSFER_REQUEST,
@@ -53,20 +57,21 @@ typedef enum {
 
 GType           gossip_event_get_gtype   (void) G_GNUC_CONST;
 GossipEvent *   gossip_event_new         (GossipEventType  type);
-gint            gossip_event_get_id      (GossipEvent     *event);
+GossipEventId   gossip_event_get_id      (GossipEvent     *event);
 GossipEventType gossip_event_get_type    (GossipEvent     *event);
 const gchar *   gossip_event_get_message (GossipEvent     *event);
 
-
 /* Should probably subclass event instead */
 GObject *       gossip_event_get_data    (GossipEvent     *event);
 void            gossip_event_set_data    (GossipEvent     *event,
 					  GObject         *data);
-gboolean        gossip_event_equal       (gconstpointer    v1,
-					  gconstpointer    v2);
 guint           gossip_event_hash        (gconstpointer    key);
+gboolean        gossip_event_equal       (gconstpointer    a,
+					  gconstpointer    b);
 gint            gossip_event_compare     (gconstpointer    a,
 					  gconstpointer    b);
 
+G_END_DECLS
+
 #endif /* __GOSSIP_EVENT_H__ */
 
