@@ -29,6 +29,8 @@
 #include "gossip-account.h"
 #include "gossip-vcard.h"
 
+G_BEGIN_DECLS
+
 #define GOSSIP_TYPE_PROTOCOL         (gossip_protocol_get_type ())
 #define GOSSIP_PROTOCOL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), GOSSIP_TYPE_PROTOCOL, GossipProtocol))
 #define GOSSIP_PROTOCOL_CLASS(k)     (G_TYPE_CHECK_CLASS_CAST((k), GOSSIP_TYPE_PROTOCOL, GossipProtocolClass))
@@ -123,9 +125,15 @@ struct _GossipProtocolClass {
 	void            (*register_account)        (GossipProtocol         *protocol,
 						    GossipAccount          *account,
 						    GossipVCard            *vcard,
-						    GossipRegisterCallback  callback,
+						    GossipResultErrorCallback  callback,
 						    gpointer                user_data);
 	void            (*register_cancel)         (GossipProtocol         *protocol);
+	void            (*change_password)         (GossipProtocol         *protocol,
+						    const gchar            *new_password,
+						    GossipResultErrorCallback  callback,
+						    gpointer                user_data);
+	void            (*change_password_cancel)  (GossipProtocol         *protocol);
+	
 	GossipAccount * (*new_account)             (GossipProtocol         *protocol);
 	void            (*get_avatar_requirements) (GossipProtocol         *protocol,
 						    guint                  *min_width,
@@ -204,9 +212,15 @@ gboolean        gossip_protocol_get_version             (GossipProtocol
 void            gossip_protocol_register_account        (GossipProtocol          *protocol,
 							 GossipAccount           *account,
 							 GossipVCard             *vcard,
-							 GossipRegisterCallback   callback,
+							 GossipResultErrorCallback callback,
 							 gpointer                 user_data);
 void            gossip_protocol_register_cancel         (GossipProtocol          *protocol);
+void            gossip_protocol_change_password         (GossipProtocol          *protocol,
+							 const gchar             *new_password,
+							 GossipResultErrorCallback callback,
+							 gpointer                 user_data);
+void            gossip_protocol_change_password_cancel  (GossipProtocol          *protocol);
+
 GossipAccount * gossip_protocol_new_account             (GossipProtocol          *protocol);
 void            gossip_protocol_get_avatar_requirements (GossipProtocol          *protocol,
 							 guint                   *min_width,
@@ -217,4 +231,6 @@ void            gossip_protocol_get_avatar_requirements (GossipProtocol
 							 gchar                  **format);
 const gchar *   gossip_protocol_error_to_string         (GossipProtocolError      error);
 
+G_END_DECLS
+
 #endif /* __GOSSIP_PROTOCOL_H__ */
