@@ -18,11 +18,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __GOSSIP_CONTACT_INFO_H__
-#define __GOSSIP_CONTACT_INFO_H__
+#ifndef __GOSSIP_CONTACT_INFO_DIALOG_H__
+#define __GOSSIP_CONTACT_INFO_DIALOG_H__
 
 #include <libgossip/gossip-contact.h>
 
-void gossip_contact_info_dialog_show (GossipContact *contact);
+G_BEGIN_DECLS
 
-#endif /* __GOSSIP_CONTACT_INFO_H__ */
+void gossip_contact_info_dialog_show (GossipContact *contact,
+				      GtkWindow     *parent);
+
+G_END_DECLS
+
+#endif /* __GOSSIP_CONTACT_INFO_DIALOG_H__ */
