@@ -28,6 +28,7 @@
 #include <libgossip/gossip-chatroom-contact.h>
 #include <libgossip/gossip-chatroom-provider.h>
 #include <libgossip/gossip-debug.h>
+#include <libgossip/gossip-log.h>
 #include <libgossip/gossip-message.h>
 
 #include "gossip-app.h"
@@ -42,7 +43,6 @@
 #include "gossip-sound.h"
 #include "gossip-stock.h"
 #include "gossip-ui-utils.h"
-#include "gossip-log.h"
 
 #define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GOSSIP_TYPE_GROUP_CHAT, GossipGroupChatPriv))
 
@@ -57,15 +57,18 @@ struct _GossipGroupChatPriv {
 	GossipChatroom         *chatroom;
 
 	GtkWidget              *widget;
+	GtkWidget              *hpaned;
+	GtkWidget              *vbox_left;
+
 	GtkWidget              *scrolled_window_chat;
 	GtkWidget              *scrolled_window_input;
 	GtkWidget              *scrolled_window_contacts;
 
 	GtkWidget              *hbox_topic;
-	GtkWidget              *entry_topic;
+	GtkWidget              *label_topic;
+	gchar                  *topic;
 
 	GtkWidget              *treeview;
-	GtkWidget              *hpaned;
 
 	gchar                  *name;
 
@@ -166,6 +169,11 @@ static void            group_chat_topic_changed_cb            (GossipChatroomPro
 							       GossipContact                *who,
 							       const gchar                  *new_topic,
 							       GossipGroupChat              *chat);
+static void            group_chat_topic_entry_activate_cb     (GtkWidget                    *entry,
+							       GtkDialog                    *dialog);
+static void            group_chat_topic_response_cb           (GtkWidget                    *dialog,
+							       gint                          response,
+							       GossipGroupChat              *chat);
 static void            group_chat_contact_joined_cb           (GossipChatroomProvider       *provider,
 							       gint                          id,
 							       GossipContact                *contact,
@@ -174,15 +182,11 @@ static void            group_chat_contact_left_cb             (GossipChatroomPro
 							       gint                          id,
 							       GossipContact                *contact,
 							       GossipGroupChat              *chat);
-static void            group_chat_contact_presence_updated_cb (GossipChatroomProvider       *provider,
-							       gint                          id,
-							       GossipContact                *contact,
+static void            group_chat_contact_presence_updated_cb (GossipContact                *contact,
+							       GParamSpec                   *param,
 							       GossipGroupChat              *chat);
-static void            group_chat_contact_updated_cb          (GossipChatroomProvider       *provider,
-							       gint                          id,
-							       GossipContact                *contact,
-							       GossipGroupChat              *chat);
-static void            group_chat_topic_activate_cb           (GtkEntry                     *entry,
+static void            group_chat_contact_updated_cb          (GossipContact                *contact,
+							       GParamSpec                   *param,
 							       GossipGroupChat              *chat);
 static void            group_chat_private_chat_new            (GossipGroupChat              *chat,
 							       GossipContact                *contact);
@@ -301,6 +305,8 @@ gossip_group_chat_init (GossipGroupChat *chat)
 
 	chatview = GOSSIP_CHAT_VIEW (GOSSIP_CHAT (chat)->view);
 	gossip_chat_view_set_is_group_chat (chatview, TRUE);
+
+	group_chat_create_ui (chat);
 }
 
 static void
@@ -360,16 +366,11 @@ group_chat_finalize (GObject *object)
 	g_signal_handlers_disconnect_by_func (priv->chatroom_provider,
 					      group_chat_contact_left_cb,
 					      chat);
-	g_signal_handlers_disconnect_by_func (priv->chatroom_provider,
-					      group_chat_contact_presence_updated_cb,
-					      chat);
-	g_signal_handlers_disconnect_by_func (priv->chatroom_provider,
-					      group_chat_contact_updated_cb,
-					      chat);
 	
 	g_object_unref (priv->chatroom_provider);
 
 	g_free (priv->name);
+	g_free (priv->topic);
 
 	g_list_foreach (priv->private_chats,
 			(GFunc) group_chat_private_chat_stop_foreach,
@@ -488,6 +489,8 @@ group_chat_join_cb (GossipChatroomProvider   *provider,
 	gtk_widget_set_sensitive (priv->scrolled_window_input, TRUE);
 
 	gossip_chat_view_append_event (chatview, _("Connected"));
+
+	gtk_widget_grab_focus (GOSSIP_CHAT (chat)->input_text_view);
 }
 
 static void
@@ -532,7 +535,7 @@ group_chat_protocol_disconnected_cb (GossipSession   *session,
 		return;
 	}
 
-	gtk_widget_set_sensitive (priv->entry_topic, FALSE);
+	gtk_widget_set_sensitive (priv->hbox_topic, FALSE);
 	gtk_widget_set_sensitive (priv->scrolled_window_contacts, FALSE);
 	gtk_widget_set_sensitive (priv->scrolled_window_input, FALSE);
 
@@ -991,8 +994,7 @@ group_chat_create_ui (GossipGroupChat *chat)
 {
 	GossipGroupChatPriv *priv;
 	GladeXML            *glade;
-	GtkWidget           *vbox_left;
-	GList               *list;
+ 	GList               *list = NULL; 
 
 	priv = GET_PRIV (chat);
 
@@ -1000,30 +1002,36 @@ group_chat_create_ui (GossipGroupChat *chat)
 				       "group_chat_widget",
 				       NULL,
 				       "group_chat_widget", &priv->widget,
+				       "hpaned", &priv->hpaned,
+				       "vbox_left", &priv->vbox_left,
 				       "scrolled_window_chat", &priv->scrolled_window_chat,
 				       "scrolled_window_input", &priv->scrolled_window_input,
 				       "hbox_topic", &priv->hbox_topic,
-				       "entry_topic", &priv->entry_topic,
-				       "treeview", &priv->treeview,
+				       "label_topic", &priv->label_topic,
 				       "scrolled_window_contacts", &priv->scrolled_window_contacts,
-				       "vbox_left", &vbox_left,
-				       "hpaned", &priv->hpaned,
+				       "treeview", &priv->treeview,
 				       NULL);
 
 	gossip_glade_connect (glade,
 			      chat,
 			      "group_chat_widget", "destroy", group_chat_widget_destroy_cb,
-			      "entry_topic", "activate", group_chat_topic_activate_cb,
 			      NULL);
 
 	g_object_unref (glade);
 
 	g_object_set_data (G_OBJECT (priv->widget), "chat", chat);
 
+	/* Add room GtkTextView. */
 	gtk_container_add (GTK_CONTAINER (priv->scrolled_window_chat),
 			   GTK_WIDGET (GOSSIP_CHAT (chat)->view));
 	gtk_widget_show (GTK_WIDGET (GOSSIP_CHAT (chat)->view));
 
+	g_signal_connect (GOSSIP_CHAT (chat)->view,
+			  "focus_in_event",
+			  G_CALLBACK (group_chat_focus_in_event_cb),
+			  chat);
+
+	/* Add input GtkTextView */
 	gtk_container_add (GTK_CONTAINER (priv->scrolled_window_input),
 			   GOSSIP_CHAT (chat)->input_text_view);
 	gtk_widget_show (GOSSIP_CHAT (chat)->input_text_view);
@@ -1033,11 +1041,6 @@ group_chat_create_ui (GossipGroupChat *chat)
 			  G_CALLBACK (group_chat_key_press_event_cb),
 			  chat);
 
-	g_signal_connect (GOSSIP_CHAT (chat)->view,
-			  "focus_in_event",
-			  G_CALLBACK (group_chat_focus_in_event_cb),
-			  chat);
-
 	/* Drag & drop */
 	gtk_drag_dest_set (GTK_WIDGET (priv->treeview),
 			   GTK_DEST_DEFAULT_ALL,
@@ -1050,18 +1053,27 @@ group_chat_create_ui (GossipGroupChat *chat)
 			  G_CALLBACK (group_chat_drag_data_received),
 			  chat);
 
-	list = NULL;
-	list = g_list_append (list, GOSSIP_CHAT (chat)->input_text_view);
-	list = g_list_append (list, priv->entry_topic);
-
-	gtk_container_set_focus_chain (GTK_CONTAINER (vbox_left), list);
-
+	/* Add nick name completion */
 	priv->completion = g_completion_new (NULL);
 	g_completion_set_compare (priv->completion,
 				  group_chat_contacts_completion_func);
 
-	gtk_widget_grab_focus (GOSSIP_CHAT (chat)->input_text_view);
 	group_chat_contacts_setup (chat);
+
+	/* Set widget focus order */
+	list = g_list_append (NULL, priv->scrolled_window_input);
+	gtk_container_set_focus_chain (GTK_CONTAINER (priv->vbox_left), list);
+	g_list_free (list);
+
+	list = g_list_append (NULL, priv->vbox_left);
+	list = g_list_append (list, priv->scrolled_window_contacts);
+	gtk_container_set_focus_chain (GTK_CONTAINER (priv->hpaned), list);
+	g_list_free (list);
+
+	list = g_list_append (NULL, priv->hpaned);
+	list = g_list_append (list, priv->hbox_topic);
+	gtk_container_set_focus_chain (GTK_CONTAINER (priv->widget), list);
+	g_list_free (list);
 }
 
 static void
@@ -1142,7 +1154,6 @@ group_chat_topic_changed_cb (GossipChatroomProvider *provider,
 {
 	GossipGroupChatPriv *priv;
 	gchar               *event;
-	gchar               *str;
 
 	priv = GET_PRIV (chat);
 
@@ -1153,15 +1164,93 @@ group_chat_topic_changed_cb (GossipChatroomProvider *provider,
 	gossip_debug (DEBUG_DOMAIN, "[%d] Topic changed by:'%s' to:'%s'",
 		      id, gossip_contact_get_id (who), new_topic);
 
-	gtk_entry_set_text (GTK_ENTRY (priv->entry_topic), new_topic);
-
-	str = g_strdup_printf (_("%s has set the topic"),
-				 gossip_contact_get_name (who));
-	event = g_strconcat (str, ": ", new_topic, NULL);
-	g_free (str);
+	g_free (priv->topic);
+	priv->topic = g_strdup (new_topic);
+	
+	gtk_label_set_text (GTK_LABEL (priv->label_topic), new_topic);
 
+	event = g_strdup_printf (_("%s has set the topic: %s"),
+				 gossip_contact_get_name (who),
+				 new_topic);
 	gossip_chat_view_append_event (GOSSIP_CHAT (chat)->view, event);
 	g_free (event);
+
+	g_signal_emit_by_name (chat, "status-changed");
+}
+
+static void
+group_chat_topic_entry_activate_cb (GtkWidget *entry,
+				    GtkDialog *dialog)
+{
+	gtk_dialog_response (dialog, GTK_RESPONSE_OK);
+}
+
+static void
+group_chat_topic_response_cb (GtkWidget       *dialog,
+			      gint             response,			      
+			      GossipGroupChat *chat)
+{
+	if (response == GTK_RESPONSE_OK) {
+		GtkWidget   *entry;
+		const gchar *topic;
+
+		entry = g_object_get_data (G_OBJECT (dialog), "entry");
+		topic = gtk_entry_get_text (GTK_ENTRY (entry));
+		
+		if (!G_STR_EMPTY (topic)) {
+			GossipGroupChatPriv *priv;
+
+			priv = GET_PRIV (chat);
+
+			gossip_chatroom_provider_change_topic (priv->chatroom_provider,
+							       gossip_chatroom_get_id (priv->chatroom),
+							       topic);
+		}
+	}
+
+	gtk_widget_destroy (dialog);
+}
+
+void
+gossip_group_chat_set_topic (GossipGroupChat *chat)
+{
+	GossipGroupChatPriv *priv;
+	GtkWidget           *dialog;
+	GtkWidget           *entry;
+	GtkWidget           *hbox;
+	const gchar         *topic;
+
+	priv = GET_PRIV (chat);
+
+	dialog = gtk_message_dialog_new (GTK_WINDOW (gossip_app_get_window ()),
+					 0,
+					 GTK_MESSAGE_QUESTION,
+					 GTK_BUTTONS_OK_CANCEL,
+					 _("Enter the new topic you want to set for this room:"));
+
+	topic = gtk_label_get_text (GTK_LABEL (priv->label_topic));
+
+	hbox = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox),
+			    hbox, FALSE, TRUE, 4);
+
+	entry = gtk_entry_new ();
+	gtk_entry_set_text (GTK_ENTRY (entry), topic);
+	gtk_editable_select_region (GTK_EDITABLE (entry), 0, -1);
+		    
+	gtk_box_pack_start (GTK_BOX (hbox), entry, TRUE, TRUE, 4);
+
+	g_object_set (GTK_MESSAGE_DIALOG (dialog)->label, "use-markup", TRUE, NULL);
+	g_object_set_data (G_OBJECT (dialog), "entry", entry);
+
+	g_signal_connect (entry, "activate",
+			  G_CALLBACK (group_chat_topic_entry_activate_cb),
+			  dialog);
+	g_signal_connect (dialog, "response",
+			  G_CALLBACK (group_chat_topic_response_cb),
+			  chat);
+
+	gtk_widget_show_all (dialog);
 }
 
 static void
@@ -1209,7 +1298,24 @@ group_chat_contact_joined_cb (GossipChatroomProvider *provider,
 
 	g_object_unref (pixbuf);
 
+	g_signal_connect (contact, "notify::presences",
+			  G_CALLBACK (group_chat_contact_presence_updated_cb),
+			  chat);
+	g_signal_connect (contact, "notify::name",
+			  G_CALLBACK (group_chat_contact_updated_cb),
+			  chat);
+
 	g_signal_emit_by_name (chat, "contact_added", contact);
+	
+	/* Add event to chatroom */
+	if (!gossip_contact_equal (priv->own_contact, contact)) {
+		gchar *str;
+
+		str = g_strdup_printf (_("%s has joined the room"),
+				       gossip_contact_get_name (contact));
+		gossip_chat_view_append_event (GOSSIP_CHAT (chat)->view, str);
+		g_free (str);
+	}
 }
 
 static void
@@ -1361,6 +1467,13 @@ group_chat_contact_left_cb (GossipChatroomProvider *provider,
 	gossip_debug (DEBUG_DOMAIN, "[%d] Contact left:'%s'",
 		      id, gossip_contact_get_id (contact));
 
+	g_signal_handlers_disconnect_by_func (contact,
+					      group_chat_contact_updated_cb,
+					      chat);
+	g_signal_handlers_disconnect_by_func (contact,
+					      group_chat_contact_presence_updated_cb,
+					      chat);
+
 	if (group_chat_contacts_find (chat, contact, &iter)) {
 		GtkTreeModel *model;
 		GtkTreeIter   parent;
@@ -1375,26 +1488,30 @@ group_chat_contact_left_cb (GossipChatroomProvider *provider,
 		}
 
 		g_signal_emit_by_name (chat, "contact_removed", contact);
+
+		/* Add event to chatroom */
+		if (!gossip_contact_equal (priv->own_contact, contact)) {
+			gchar *str;
+			str = g_strdup_printf (_("%s has left the room"),
+					       gossip_contact_get_name (contact));
+			gossip_chat_view_append_event (GOSSIP_CHAT (chat)->view, str);
+			g_free (str);
+		}
 	}
 }
 
 static void
-group_chat_contact_presence_updated_cb (GossipChatroomProvider *provider,
-					gint                    id,
-					GossipContact          *contact,
-					GossipGroupChat        *chat)
+group_chat_contact_presence_updated_cb (GossipContact   *contact,
+					GParamSpec      *param,
+					GossipGroupChat *chat)
 {
 	GossipGroupChatPriv *priv;
 	GtkTreeIter          iter;
 
 	priv = GET_PRIV (chat);
 
-	if (id != gossip_chatroom_get_id (priv->chatroom)) {
-		return;
-	}
-
-	gossip_debug (DEBUG_DOMAIN, "[%d] Contact Presence Updated:'%s'",
-		      id, gossip_contact_get_id (contact));
+	gossip_debug (DEBUG_DOMAIN, "Contact Presence Updated:'%s'",
+		      gossip_contact_get_id (contact));
 
 	if (group_chat_contacts_find (chat, contact, &iter)) {
 		GdkPixbuf    *pixbuf;
@@ -1409,27 +1526,23 @@ group_chat_contact_presence_updated_cb (GossipChatroomProvider *provider,
 				    -1);
 
 		gdk_pixbuf_unref (pixbuf);
-
-		g_signal_emit_by_name (chat, "contact_presence_updated",
-				       contact);
+	} else {
+		g_signal_handlers_disconnect_by_func (contact,
+						      group_chat_contact_presence_updated_cb,
+						      chat);
 	}
 }
 
 static void
-group_chat_contact_updated_cb (GossipChatroomProvider *provider,
-			       gint                    id,
-			       GossipContact          *contact,
-			       GossipGroupChat        *chat)
+group_chat_contact_updated_cb (GossipContact   *contact,
+			       GParamSpec      *param,
+			       GossipGroupChat *chat)
 {
 	GossipGroupChatPriv *priv;
 	GtkTreeIter          iter;
 
 	priv = GET_PRIV (chat);
 
-	if (id != gossip_chatroom_get_id (priv->chatroom)) {
-		return;
-	}
-
 	if (group_chat_contacts_find (chat, contact, &iter)) {
 		GtkTreeModel *model;
 
@@ -1438,26 +1551,13 @@ group_chat_contact_updated_cb (GossipChatroomProvider *provider,
 				    &iter,
 				    COL_NAME, gossip_contact_get_name (contact),
 				    -1);
-
-		g_signal_emit_by_name (chat, "contact_updated", contact);
+	} else {
+		g_signal_handlers_disconnect_by_func (contact,
+						      group_chat_contact_updated_cb,
+						      chat);
 	}
 }
 
-static void
-group_chat_topic_activate_cb (GtkEntry *entry,
-			      GossipGroupChat *chat)
-{
-	GossipGroupChatPriv *priv;
-
-	priv = GET_PRIV (chat);
-
-	gossip_chatroom_provider_change_topic (priv->chatroom_provider,
-					       gossip_chatroom_get_id (priv->chatroom),
-					       gtk_entry_get_text (entry));
-
-	gtk_widget_grab_focus (GOSSIP_CHAT (chat)->input_text_view);
-}
-
 static void
 group_chat_private_chat_new (GossipGroupChat *chat,
 			     GossipContact   *contact)
@@ -1658,6 +1758,16 @@ group_chat_get_tooltip (GossipChat *chat)
 	group_chat = GOSSIP_GROUP_CHAT (chat);
 	priv = GET_PRIV (group_chat);
 
+	if (priv->topic) {
+		gchar *topic, *tmp;
+
+		topic = g_strdup_printf (_("Topic: %s"), priv->topic);
+		tmp = g_strdup_printf ("%s\n%s", priv->name, topic);
+		g_free (topic);
+
+		return tmp;
+	}
+
 	return g_strdup (priv->name);
 }
 
@@ -1941,9 +2051,7 @@ gossip_group_chat_new (GossipChatroomProvider *provider,
 
 	priv->private_chats = NULL;
 
-	group_chat_create_ui (chat);
-
-	g_hash_table_insert (group_chats, GINT_TO_POINTER (id), chat);
+ 	g_hash_table_insert (group_chats, GINT_TO_POINTER (id), chat);
 
 	g_signal_connect (provider, "chatroom-new-message",
 			  G_CALLBACK (group_chat_new_message_cb),
@@ -1960,12 +2068,6 @@ gossip_group_chat_new (GossipChatroomProvider *provider,
 	g_signal_connect (provider, "chatroom-contact-left",
 			  G_CALLBACK (group_chat_contact_left_cb),
 			  chat);
-	g_signal_connect (provider, "chatroom-contact-presence-updated",
-			  G_CALLBACK (group_chat_contact_presence_updated_cb),
-			  chat);
-	g_signal_connect (provider, "chatroom-contact-updated",
-			  G_CALLBACK (group_chat_contact_updated_cb),
-			  chat);
 
 	/* Actually join the chat room */
 	group_chat_join (chat);
@@ -1977,7 +2079,8 @@ gossip_group_chat_new (GossipChatroomProvider *provider,
 	 * from the provider by id and if we haven't started the join,
 	 * it officially doesn't exist according to the backend.
 	 */
-	gossip_chat_present (GOSSIP_CHAT (chat));
+	
+ 	gossip_chat_present (GOSSIP_CHAT (chat)); 
 
 	priv->scroll_idle_id = g_idle_add ((GSourceFunc) 
 					   group_chat_scroll_down_idle_func, 
