@@ -25,11 +25,11 @@
 #include <gtk/gtk.h>
 
 #include <libgossip/gossip-debug.h>
+#include <libgossip/gossip-log.h>
 #include <libgossip/gossip-utils.h>
 
 #include "gossip-app.h"
 #include "gossip-account-chooser.h"
-#include "gossip-log.h"
 #include "gossip-log-window.h"
 #include "gossip-ui-utils.h"
 
