@@ -72,9 +72,16 @@ static void                notify_protocol_disconnected_cb        (GossipSession
 								   GossipProtocol     *protocol,
 								   gint                reason,
 								   gpointer            user_data);
-static void                notify_contact_presence_updated_cb     (GossipSession      *session,
+static void                notify_contact_presence_updated_cb     (GossipContact      *contact,
+								   GParamSpec         *param,
+								   gpointer            user_data);
+static void                notify_contact_added_cb                (GossipSession      *session,
 								   GossipContact      *contact,
 								   gpointer            user_data);
+static void                notify_contact_removed_cb              (GossipSession      *session,
+								   GossipContact      *contact,
+								   gpointer            user_data);
+static void                notify_contact_remove                  (GossipContact      *contact);
 static gboolean            notify_subscription_request_show_cb    (GossipContact      *contact);
 static void                notify_event_added_cb                  (GossipEventManager *event_manager,
 								   GossipEvent        *event,
@@ -547,12 +554,13 @@ notify_protocol_connected_cb (GossipSession  *session,
 	id = g_timeout_add (NOTIFY_WAIT_TIME,
 			    (GSourceFunc) notify_protocol_timeout_cb,
 			    account);
-	g_hash_table_insert (account_states, account, GUINT_TO_POINTER (id));
+	g_hash_table_insert (account_states, g_object_ref (account),
+			     GUINT_TO_POINTER (id));
 }
 
 static void
-notify_contact_presence_updated_cb (GossipSession *session,
-				    GossipContact *contact,
+notify_contact_presence_updated_cb (GossipContact *contact,
+				    GParamSpec    *param,
 				    gpointer       user_data)
 {
 	GossipPresence *presence;
@@ -591,6 +599,36 @@ notify_contact_presence_updated_cb (GossipSession *session,
 	}
 }
 
+static void
+notify_contact_added_cb (GossipSession *session,
+			 GossipContact *contact,
+			 gpointer       user_data)
+{
+	g_signal_connect (contact, "notify::presences",
+			  G_CALLBACK (notify_contact_presence_updated_cb),
+			  NULL);
+	g_signal_connect (contact, "notify::type",
+			  G_CALLBACK (notify_contact_presence_updated_cb),
+			  NULL);
+}
+
+static void
+notify_contact_removed_cb (GossipSession *session,
+			   GossipContact *contact,
+			   gpointer       user_data)
+{
+	g_hash_table_remove (contact_states, contact);
+}
+
+static void
+notify_contact_remove (GossipContact *contact)
+{
+	g_signal_handlers_disconnect_by_func (contact,
+					      notify_contact_presence_updated_cb,
+					      NULL);
+	g_object_unref (contact);
+}
+
 static gboolean
 notify_subscription_request_show_cb (GossipContact *contact)
 {
@@ -806,7 +844,7 @@ gossip_notify_init (GossipSession      *session,
 
 	contact_states = g_hash_table_new_full (gossip_contact_hash,
 						gossip_contact_equal,
-						(GDestroyNotify) g_object_unref,
+						(GDestroyNotify) notify_contact_remove,
 						(GDestroyNotify) g_object_unref);
 
 	g_signal_connect (session, "protocol-connected",
@@ -815,8 +853,11 @@ gossip_notify_init (GossipSession      *session,
 	g_signal_connect (session, "protocol-disconnected",
 			  G_CALLBACK (notify_protocol_disconnected_cb),
 			  NULL);
-	g_signal_connect (session, "contact-presence-updated",
-			  G_CALLBACK (notify_contact_presence_updated_cb),
+	g_signal_connect (session, "contact-added",
+			  G_CALLBACK (notify_contact_added_cb),
+			  NULL);
+	g_signal_connect (session, "contact-removed",
+			  G_CALLBACK (notify_contact_removed_cb),
 			  NULL);
 
 	g_signal_connect (event_manager, "event-added",
